**************
``matplotlib``
**************

.. py:currentmodule:: matplotlib

.. autofunction:: use

.. autofunction:: get_backend

.. py:data:: rcParams

    An instance of :class:`RcParams` for handling default matplotlib values.

.. autofunction:: rc_context

.. autofunction:: rc

.. autofunction:: rc_file

.. autofunction:: rcdefaults

.. autofunction:: rc_file_defaults

.. autoclass:: RcParams

.. autofunction:: rc_params

.. autofunction:: rc_params_from_file

.. autofunction:: matplotlib_fname

.. autofunction:: interactive

.. autofunction:: is_interactive

.. autofunction:: set_loglevel
